.. _recipe_asr.bse:

asr.bse
=======


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.bse`-recipe.
This recipe is comprised of 2 steps, namely:

  - :py:func:`asr.bse.calculate`
  - :py:func:`asr.bse.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.bse

or as a python module

.. code-block:: console

   $ python -m asr.bse

Detailed description
--------------------
Bethe Salpeter absorption spectrum.

Steps
-----


asr.bse@calculate
^^^^^^^^^^^^^^^^^
.. autofunction:: asr.bse.calculate
   

asr.bse
^^^^^^^
.. autofunction:: asr.bse.main
   